@@ -10,12 +10,12 @@ HTML::SocialMedia - Put social media links into your website
 
 =head1 VERSION
 
-Version 0.24
+Version 0.25
 
 =cut
 
-our $VERSION = '0.24';
-use constant DEFAULTFACEBOOKURL => "//connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v2.4";
+our $VERSION = '0.25';
+use constant DEFAULTFACEBOOKURL => "https://connect.facebook.net/en_GB/sdk.js#xfbml=1&version=v2.4";
 
 =head1 SYNOPSIS
 
@@ -294,24 +294,18 @@ END
 		}
 
 		$rc .= << 'END';
-			<div id="facebook">
 			<div id="fb-root"></div>
-			<script type="text/javascript">
-				document.write('<' + 'fb:like send="false" layout="button_count" width="100" show_faces="false" font=""></fb:like>');
-				var s = document.createElement('SCRIPT'), s1 = document.getElementsByTagName('HEAD')[0];
-				s.type = 'text/javascript';
-				s.async = true;
-			<div id="fb-root"></div>
-			<script>(function(d, s, id) {
-				var js, fjs = d.getElementsByTagName(s)[0];
-				if (d.getElementById(id)) return;
-				js = d.createElement(s); js.id = id;
+			<script>
+				(function(d, s, id) {
+					var js, fjs = d.getElementsByTagName(s)[0];
+					if (d.getElementById(id)) return;
+					js = d.createElement(s); js.id = id;
 END
-		$rc .= "js.src = http:\"$url\";";
+		$rc .= "js.src = \"$url\";";
 		$rc .= << 'END';
-				fjs.parentNode.insertBefore(js, fjs);
-				}(document, 'script', 'facebook-jssdk'));
-			</script>
+					fjs.parentNode.insertBefore(js, fjs);
+					}(document, 'script', 'facebook-jssdk'));
+				</script>
 END
 		my $host_name;
 		unless($self->{info}) {
